#
# spec file for package python-json5
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-json5
Version:        0.9.4
Release:        lp152.2.1
Summary:        A Python implementation of the JSON5 data format
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/dpranke/pyjson5
Source:         https://github.com/dpranke/pyjson5/archive/v%{version}.tar.gz#/pyjson5-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A Python implementation of the JSON5 data format.

JSON5 extends the JSON data interchange format to make it
slightly more usable as a configuration language:

  * JavaScript-style comments (both single and multi-line) are legal.
  * Object keys may be unquoted if they are legal ECMAScript identifiers
  * Objects and arrays may end with trailing commas.
  * Strings can be single-quoted, and multi-line string literals are allowed.

%prep
%setup -q -n pyjson5-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/pyjson5
%python_expand rm -rf %{buildroot}%{$python_sitelib}/tests
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative pyjson5

%postun
%python_uninstall_alternative pyjson5

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/pyjson5
%{python_sitelib}/*

%changelog
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Apr 16 2020 pgajdos@suse.com
- version update to 0.9.4
  * v0.9.4 (2020-03-26)
  * [GitHub pull #38](https://github.com/dpranke/pyjson5/pull/38)
    Fix from fredrik@fornwall.net for dumps() crashing when passed
    an empty string as a key in an object.
  * v0.9.3 (2020-03-17)
  * [GitHub pull #35](https://github.com/dpranke/pyjson5/pull/35)
    Fix from pastelmind@ for dump() not passing the right args to dumps().
  * Fix from p.skouzos@novafutur.com to remove the tests directory from
    the setup call, making the package a bit smaller.
  * v0.9.2 (2020-03-02)
  * [GitHub pull #34](https://github.com/dpranke/pyjson5/pull/34)
    Fix from roosephu@ for a badly formatted nested list.
  * v0.9.1 (2020-02-09)
  * [GitHub issue #33](https://github.com/dpranke/pyjson5/issues/33):
    Fix stray trailing comma when dumping an object with an invalid key.
  * v0.9.0 (2020-01-30)
  * [GitHub issue #29](https://github.com/dpranke/pyjson5/issues/29):
    Fix an issue where objects keys that started with a reserved
    word were incorrectly quoted.
  * [GitHub issue #30](https://github.com/dpranke/pyjson5/issues/30):
    Fix an issue where dumps() incorrectly thought a data structure
    was cyclic in some cases.
  * [GitHub issue #32](https://github.com/dpranke/pyjson5/issues/32):
    Allow for non-string keys in dicts passed to ``dump()``/``dumps()``.
    Add an ``allow_duplicate_keys=False`` to prevent possible
    ill-formed JSON that might result.
* Mon Jul 29 2019 Todd R <toddrme2178@gmail.com>
- Initial version
